<?php

/**
 * 客户管理
 * 用于管理客户信息，包括批发客户、零售客户、代理商
 */

session_start();
require_once '../config.php';

// 检查用户是否已登录
if (!isset($_SESSION['user_id'])) {
    header('Location: ../login.php');
    exit;
}

// 设置页面标题
$page_title = "客户管理";

// 初始化变量
$success = '';
$error = '';

// 获取筛选参数
$search = isset($_GET['search']) ? trim($_GET['search']) : '';
$customer_type = isset($_GET['type']) ? $_GET['type'] : '';
$region = isset($_GET['region']) ? $_GET['region'] : '';
$status = isset($_GET['status']) ? intval($_GET['status']) : -1; // -1表示全部，1表示启用，0表示禁用

// 检查客户表是否存在
try {
    $stmt = $pdo->query("SHOW TABLES LIKE 'customers'");
    if (!$stmt->rowCount()) {
        // 从SQL文件中提取customers表定义并创建
        $sql_file = file_get_contents('../SQL/FruitEase.sql');

        if (preg_match('/CREATE TABLE\s+`customers`\s*\((.*?)\)\s*ENGINE/s', $sql_file, $matches)) {
            $create_customers_sql = "CREATE TABLE `customers` (" . $matches[1] . ") ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '客户信息表'";
            $pdo->exec($create_customers_sql);

            // 提取INSERT语句
            if (preg_match('/INSERT INTO\s+`customers`(.*?);/s', $sql_file, $insert_matches)) {
                $insert_customers_sql = "INSERT INTO `customers`" . $insert_matches[1];
                $pdo->exec($insert_customers_sql);
                $success = "已从SQL文件创建customers表并插入初始数据";
            }
        } else {
            // 如果在SQL文件中找不到定义，则使用以下备用定义
            $pdo->exec("
                CREATE TABLE `customers` (
                  `id` INT UNSIGNED NOT NULL AUTO_INCREMENT COMMENT '客户ID',
                  `name` VARCHAR(100) NOT NULL COMMENT '客户名称',
                  `type` ENUM(
                    'wholesale',
                    'retail',
                    'distributor',
                    'ecommerce'
                  ) NOT NULL COMMENT '客户类型',
                  `contact_person` VARCHAR(50) DEFAULT NULL COMMENT '联系人',
                  `phone` VARCHAR(20) DEFAULT NULL COMMENT '联系电话',
                  `email` VARCHAR(100) UNIQUE DEFAULT NULL COMMENT '邮箱',
                  `address` VARCHAR(255) DEFAULT NULL COMMENT '地址',
                  `region` VARCHAR(50) DEFAULT NULL COMMENT '区域',
                  `join_date` DATE DEFAULT NULL COMMENT '成为客户日期',
                  `credit_limit` DECIMAL(12, 2) DEFAULT NULL COMMENT '信用额度',
                  `is_active` BOOLEAN DEFAULT TRUE COMMENT '是否启用',
                  `created_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                  `updated_at` TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
                  PRIMARY KEY (`id`),
                  KEY `idx_cust_name` (`name`),
                  KEY `idx_cust_type` (`type`),
                  KEY `idx_cust_region` (`region`)
                ) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COLLATE = utf8mb4_unicode_ci COMMENT = '客户信息表'
            ");

            // 插入示例数据
            $pdo->exec("
                INSERT INTO
                  `customers` (
                    `name`,
                    `type`,
                    `contact_person`,
                    `phone`,
                    `email`,
                    `address`,
                    `region`,
                    `join_date`
                  )
                VALUES
                  (
                    '华南食品批发市场A栋3号',
                    'wholesale',
                    '刘经理',
                    '13511112222',
                    'liujingli@huanan.com',
                    '广东省广州市白云区市场路1号',
                    '华南',
                    '2023-05-10'
                  ),
                  (
                    '美味零食连锁超市',
                    'retail',
                    '采购部张三',
                    '020-88889999',
                    'caigou@meiwei.com',
                    '上海市浦东新区世纪大道100号',
                    '华东',
                    '2023-08-15'
                  ),
                  (
                    '电商平台旗舰店',
                    'ecommerce',
                    '店长小李',
                    '13788889999',
                    'fruitease@shop.com',
                    '线上地址',
                    '全国',
                    '2024-01-01'
                  ),
                  (
                    '西北区域代理商',
                    'distributor',
                    '马先生',
                    '13977778888',
                    'maxiansheng@xibei.com',
                    '陕西省西安市高新区科技路5号',
                    '西北',
                    '2023-11-20'
                  )
            ");
            $success = "已创建customers表并插入示例数据";
        }
    }

    // 处理添加/编辑客户表单提交
    if (isset($_POST['save_customer'])) {
        $id = isset($_POST['id']) ? intval($_POST['id']) : 0;
        $name = trim($_POST['name']);
        $type = $_POST['type'];
        $contact_person = trim($_POST['contact_person']);
        $phone = trim($_POST['phone']);
        $email = trim($_POST['email']);
        $address = trim($_POST['address']);
        $region = trim($_POST['region']);
        $join_date = $_POST['join_date'];
        $credit_limit = !empty($_POST['credit_limit']) ? floatval($_POST['credit_limit']) : null;
        $is_active = isset($_POST['is_active']) ? 1 : 0;

        // 验证必填字段
        if (empty($name) || empty($type)) {
            $error = "客户名称和客户类型为必填项！";
        } else {
            try {
                if ($id > 0) {
                    // 更新客户
                    $stmt = $pdo->prepare("
                        UPDATE customers SET 
                            name = ?, 
                            type = ?, 
                            contact_person = ?, 
                            phone = ?, 
                            email = ?, 
                            address = ?, 
                            region = ?, 
                            join_date = ?, 
                            credit_limit = ?,
                            is_active = ?
                        WHERE id = ?
                    ");
                    $stmt->execute([
                        $name,
                        $type,
                        $contact_person,
                        $phone,
                        $email,
                        $address,
                        $region,
                        $join_date,
                        $credit_limit,
                        $is_active,
                        $id
                    ]);
                    $success = "客户信息已更新！";
                } else {
                    // 添加新客户
                    $stmt = $pdo->prepare("
                        INSERT INTO customers (
                            name, 
                            type, 
                            contact_person, 
                            phone, 
                            email, 
                            address, 
                            region, 
                            join_date, 
                            credit_limit,
                            is_active
                        ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?)
                    ");
                    $stmt->execute([
                        $name,
                        $type,
                        $contact_person,
                        $phone,
                        $email,
                        $address,
                        $region,
                        $join_date,
                        $credit_limit,
                        $is_active
                    ]);
                    $success = "客户已成功添加！";
                }

                // 记录操作日志
                if (isset($_SESSION['user_id']) && isset($_SESSION['username'])) {
                    $action = $id > 0 ? '更新客户' : '创建客户';
                    $details = json_encode([
                        'id' => $id > 0 ? $id : $pdo->lastInsertId(),
                        'name' => $name,
                        'type' => $type
                    ]);

                    $stmt = $pdo->prepare("
                        INSERT INTO activity_log (
                            user_id, 
                            username, 
                            action, 
                            target_type, 
                            target_id, 
                            details, 
                            ip_address
                        ) VALUES (?, ?, ?, ?, ?, ?, ?)
                    ");
                    $stmt->execute([
                        $_SESSION['user_id'],
                        $_SESSION['username'],
                        $action,
                        'customer',
                        $id > 0 ? $id : $pdo->lastInsertId(),
                        $details,
                        $_SERVER['REMOTE_ADDR']
                    ]);
                }
            } catch (PDOException $e) {
                $error = "保存客户失败：" . $e->getMessage();
            }
        }
    }

    // 处理客户状态切换
    if (isset($_GET['toggle_status']) && $_GET['toggle_status'] > 0) {
        $customer_id = intval($_GET['toggle_status']);
        $new_status = isset($_GET['active']) && $_GET['active'] == 1 ? 1 : 0;

        try {
            $stmt = $pdo->prepare("UPDATE customers SET is_active = ? WHERE id = ?");
            $stmt->execute([$new_status, $customer_id]);

            // 记录操作日志
            if (isset($_SESSION['user_id']) && isset($_SESSION['username'])) {
                $action = $new_status ? '启用客户' : '禁用客户';
                $stmt = $pdo->prepare("
                    INSERT INTO activity_log (
                        user_id, 
                        username, 
                        action, 
                        target_type, 
                        target_id, 
                        details, 
                        ip_address
                    ) VALUES (?, ?, ?, ?, ?, ?, ?)
                ");
                $stmt->execute([
                    $_SESSION['user_id'],
                    $_SESSION['username'],
                    $action,
                    'customer',
                    $customer_id,
                    json_encode(['is_active' => $new_status]),
                    $_SERVER['REMOTE_ADDR']
                ]);
            }

            $success = $new_status ? "客户已启用！" : "客户已禁用！";
        } catch (PDOException $e) {
            $error = "更改客户状态失败：" . $e->getMessage();
        }
    }

    // 获取所有地区
    $regions = $pdo->query("SELECT DISTINCT region FROM customers WHERE region IS NOT NULL AND region != '' ORDER BY region")->fetchAll(PDO::FETCH_COLUMN);

    // 构建查询
    $sql = "SELECT * FROM customers WHERE 1=1";
    $params = [];

    if (!empty($search)) {
        $sql .= " AND (name LIKE ? OR contact_person LIKE ? OR phone LIKE ? OR email LIKE ?)";
        $search_param = "%$search%";
        $params[] = $search_param;
        $params[] = $search_param;
        $params[] = $search_param;
        $params[] = $search_param;
    }

    if (!empty($customer_type)) {
        $sql .= " AND type = ?";
        $params[] = $customer_type;
    }

    if (!empty($region)) {
        $sql .= " AND region = ?";
        $params[] = $region;
    }

    if ($status != -1) {
        $sql .= " AND is_active = ?";
        $params[] = $status;
    }

    $sql .= " ORDER BY name";

    $stmt = $pdo->prepare($sql);
    $stmt->execute($params);
    $customers = $stmt->fetchAll();

    // 获取要编辑的客户信息
    $edit_data = null;
    if (isset($_GET['edit']) && $_GET['edit'] > 0) {
        $edit_id = intval($_GET['edit']);
        $stmt = $pdo->prepare("SELECT * FROM customers WHERE id = ?");
        $stmt->execute([$edit_id]);
        $edit_data = $stmt->fetch();
    }
} catch (PDOException $e) {
    $error = "数据库错误：" . $e->getMessage();
}

// 客户类型映射
$customer_types = [
    'wholesale' => '批发客户',
    'retail' => '零售客户',
    'distributor' => '代理商',
    'ecommerce' => '电商客户'
];

?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title><?= htmlspecialchars($page_title) ?> - <?= title ?></title>
    <link rel="stylesheet" href="./style.css">
</head>

<body>
    <div class="content">
        <h1><?= htmlspecialchars($page_title) ?></h1>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <!-- 筛选与搜索 -->
        <div class="filter-container">
            <form action="" method="GET" class="search-bar">
                <input type="text" name="search" placeholder="搜索客户名称、联系人或电话..." value="<?= htmlspecialchars($search) ?>">

                <select name="type" title="客户类型">
                    <option value="">所有类型</option>
                    <?php foreach ($customer_types as $key => $value): ?>
                        <option value="<?= $key ?>" <?= $customer_type === $key ? 'selected' : '' ?>><?= $value ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="region" title="地区">
                    <option value="">所有地区</option>
                    <?php foreach ($regions as $r): ?>
                        <option value="<?= $r ?>" <?= $region === $r ? 'selected' : '' ?>><?= htmlspecialchars($r) ?></option>
                    <?php endforeach; ?>
                </select>

                <select name="status" title="状态">
                    <option value="-1" <?= $status === -1 ? 'selected' : '' ?>>全部</option>
                    <option value="1" <?= $status === 1 ? 'selected' : '' ?>>启用</option>
                    <option value="0" <?= $status === 0 ? 'selected' : '' ?>>禁用</option>
                </select>

                <button type="submit">搜索</button>
                <button type="button" onclick="location.href='customer_management.php'" class="btn-secondary">重置</button>
            </form>
        </div>

        <!-- 添加/编辑客户表单 -->
        <div class="form-container">
            <h2><?= $edit_data ? '编辑客户' : '添加新客户' ?></h2>
            <form method="POST" action="">
                <?php if ($edit_data): ?>
                    <input type="hidden" name="id" value="<?= $edit_data['id'] ?>">
                <?php endif; ?>

                <div class="form-group">
                    <label for="name">客户名称 <span class="required">*</span></label>
                    <input type="text" id="name" name="name" value="<?= $edit_data ? htmlspecialchars($edit_data['name']) : '' ?>" required>
                </div>

                <div class="form-group">
                    <label for="type">客户类型 <span class="required">*</span></label>
                    <select id="type" name="type" required>
                        <option value="">-- 请选择 --</option>
                        <?php foreach ($customer_types as $key => $value): ?>
                            <option value="<?= $key ?>" <?= $edit_data && $edit_data['type'] === $key ? 'selected' : '' ?>><?= $value ?></option>
                        <?php endforeach; ?>
                    </select>
                </div>

                <div class="form-row">
                    <div class="form-group">
                        <label for="contact_person">联系人</label>
                        <input type="text" id="contact_person" name="contact_person" value="<?= $edit_data ? htmlspecialchars($edit_data['contact_person']) : '' ?>">
                    </div>

                    <div class="form-group">
                        <label for="phone">联系电话</label>
                        <input type="text" id="phone" name="phone" value="<?= $edit_data ? htmlspecialchars($edit_data['phone']) : '' ?>">
                    </div>
                </div>

                <div class="form-group">
                    <label for="email">邮箱</label>
                    <input type="email" id="email" name="email" value="<?= $edit_data ? htmlspecialchars($edit_data['email']) : '' ?>">
                </div>

                <div class="form-group">
                    <label for="address">地址</label>
                    <input type="text" id="address" name="address" value="<?= $edit_data ? htmlspecialchars($edit_data['address']) : '' ?>">
                </div>

                <div class="form-row">
                    <div class="form-group">
                        <label for="region">地区</label>
                        <input type="text" id="region" name="region" value="<?= $edit_data ? htmlspecialchars($edit_data['region']) : '' ?>" placeholder="例如：华东、华南、西北...">
                    </div>

                    <div class="form-group">
                        <label for="join_date">成为客户日期</label>
                        <input type="date" id="join_date" name="join_date" value="<?= $edit_data ? $edit_data['join_date'] : date('Y-m-d') ?>">
                    </div>
                </div>

                <div class="form-row">
                    <div class="form-group">
                        <label for="credit_limit">信用额度 (¥)</label>
                        <input type="number" id="credit_limit" name="credit_limit" step="0.01" min="0" value="<?= $edit_data && $edit_data['credit_limit'] ? $edit_data['credit_limit'] : '' ?>" placeholder="0.00">
                    </div>

                    <div class="form-group checkbox-group">
                        <label>
                            <input type="checkbox" name="is_active" <?= $edit_data ? ($edit_data['is_active'] ? 'checked' : '') : 'checked' ?>>
                            启用客户
                        </label>
                    </div>
                </div>

                <div class="form-actions">
                    <button type="submit" name="save_customer" class="btn-primary"><?= $edit_data ? '更新客户' : '添加客户' ?></button>
                    <?php if ($edit_data): ?>
                        <button type="button" onclick="location.href='customer_management.php'" class="btn-secondary">取消</button>
                    <?php endif; ?>
                </div>
            </form>
        </div>

        <!-- 客户列表 -->
        <div class="table-container">
            <h2>客户列表</h2>
            <?php if (empty($customers)): ?>
                <div class="empty-state">
                    <p>暂无客户数据</p>
                </div>
            <?php else: ?>
                <table>
                    <thead>
                        <tr>
                            <th>客户名称</th>
                            <th>类型</th>
                            <th>联系人</th>
                            <th>联系电话</th>
                            <th>地区</th>
                            <th>加入日期</th>
                            <th>信用额度</th>
                            <th>状态</th>
                            <th>操作</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($customers as $customer): ?>
                            <tr class="<?= $customer['is_active'] ? '' : 'warning-row' ?>">
                                <td><?= htmlspecialchars($customer['name']) ?></td>
                                <td><?= isset($customer_types[$customer['type']]) ? $customer_types[$customer['type']] : $customer['type'] ?></td>
                                <td><?= htmlspecialchars($customer['contact_person'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($customer['phone'] ?: '-') ?></td>
                                <td><?= htmlspecialchars($customer['region'] ?: '-') ?></td>
                                <td><?= $customer['join_date'] ? date('Y-m-d', strtotime($customer['join_date'])) : '-' ?></td>
                                <td><?= $customer['credit_limit'] ? '¥' . number_format($customer['credit_limit'], 2) : '-' ?></td>
                                <td>
                                    <span class="status-tag <?= $customer['is_active'] ? 'completed' : 'cancelled' ?>">
                                        <?= $customer['is_active'] ? '启用' : '禁用' ?>
                                    </span>
                                </td>
                                <td>
                                    <a href="?edit=<?= $customer['id'] ?>" class="btn-edit">编辑</a>
                                    <?php if ($customer['is_active']): ?>
                                        <a href="?toggle_status=<?= $customer['id'] ?>&active=0" class="btn-delete" onclick="return confirm('确定要禁用该客户吗？')">禁用</a>
                                    <?php else: ?>
                                        <a href="?toggle_status=<?= $customer['id'] ?>&active=1" class="btn-primary" onclick="return confirm('确定要启用该客户吗？')">启用</a>
                                    <?php endif; ?>
                                </td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php endif; ?>
        </div>
    </div>

    <style>
        /* 补充样式 */
        .content {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .form-row {
            display: grid;
            grid-template-columns: 1fr 1fr;
            gap: 20px;
        }

        .checkbox-group {
            display: flex;
            align-items: center;
            margin-top: 30px;
        }

        .checkbox-group input[type="checkbox"] {
            width: auto;
            margin-right: 10px;
        }

        .form-actions {
            display: flex;
            justify-content: flex-start;
            gap: 10px;
            margin-top: 20px;
        }

        .required {
            color: #e74c3c;
        }

        /* 响应式调整 */
        @media (max-width: 768px) {
            .form-row {
                grid-template-columns: 1fr;
                gap: 0;
            }
        }
    </style>
</body>

</html>