<?php
// index.php
declare(strict_types=1);
require_once './config.php';
session_start();

// 登录验证
if (!isset($_SESSION['user_id'])) {
    header("Location: ./login.php");
    exit;
}

// 获取用户信息
try {
    $stmt = $pdo->prepare("
        SELECT 
            username,
            (SELECT name FROM roles WHERE id = users.role_id) AS role_name
        FROM users 
        WHERE id = ?
    ");
    $stmt->execute([$_SESSION['user_id']]);
    $userInfo = $stmt->fetch(PDO::FETCH_ASSOC);
    $displayRole = $userInfo['role_name'] ?? '未授权用户';
} catch (PDOException $e) {
    die("用户信息获取失败: " . $e->getMessage());
}

// 系统核心模块 - 根据要求.txt进行调整
$modules = [
    [
        'name' => '供应链与原料管理',
        'url' => './supply/index.php',
        'features' => [
            '✓ 供应商管理',
            '✓ 原材料采购',
            '✓ 采购价格分析',
            '✓ 采购入库与质检',
            '✓ 供应商评级'
        ]
    ],
    [
        'name' => '生产加工管理',
        'url' => './production/index.php',
        'features' => [
            '✓ 生产计划与排产',
            '✓ 生产流程管理',
            '✓ 加工批次追踪',
            '✓ 设备管理与维护',
            '✓ 生产效率分析'
        ]
    ],
    [
        'name' => '质量控制与食品安全',
        'url' => './quality/index.php',
        'features' => [
            '✓ 原材料质检',
            '✓ 生产过程监控',
            '✓ 成品检测与抽样',
            '✓ 食品安全溯源',
            '✓ 认证管理'
        ]
    ],
    [
        'name' => '库存管理',
        'url' => './inventory/index.php',
        'features' => [
            '✓ 原料库存管理',
            '✓ 半成品库存管理',
            '✓ 成品库存管理',
            '✓ 库存盘点与分析',
            '✓ 仓库环境管理'
        ]
    ],
    [
        'name' => '订单与销售管理',
        'url' => './sales/index.php',
        'features' => [
            '✓ 订单管理与处理',
            '✓ 销售渠道管理',
            '✓ 销售价格管理',
            '✓ 促销与折扣',
            '✓ 销售统计分析'
        ]
    ],
    [
        'name' => '财务管理',
        'url' => './finance/index.php',
        'features' => [
            '✓ 采购成本核算',
            '✓ 生产成本分析',
            '✓ 销售收入统计',
            '✓ 利润分析',
            '✓ 应收应付管理'
        ]
    ],
    [
        'name' => '物流与配送管理',
        'url' => './logistics/index.php',
        'features' => [
            '✓ 物流公司管理',
            '✓ 发货单管理',
            '✓ 物流追踪',
            '✓ 配送成本分析',
            '✓ 运输方案优化'
        ]
    ],
    [
        'name' => '客户与市场管理',
        'url' => './crm/index.php',
        'features' => [
            '✓ 客户信息管理',
            '✓ 客户订单历史',
            '✓ 市场营销策略',
            '✓ 客户反馈管理',
            '✓ 客户满意度分析'
        ]
    ],
    [
        'name' => '报表与数据分析',
        'url' => './analytics/index.php',
        'features' => [
            '✓ 销售数据分析',
            '✓ 生产数据分析',
            '✓ 库存数据分析',
            '✓ 财务数据分析',
            '✓ 趋势预测'
        ]
    ],
    [
        'name' => '系统设置',
        'url' => './system/index.php',
        'features' => [
            '✓ 用户角色管理',
            '✓ 权限控制',
            '✓ 数据备份与恢复',
            '✓ 操作日志',
            '✓ 系统参数配置'
        ]
    ]
];
?>

<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>果易管系统</title>
    <link href="https://cdn.bootcdn.net/ajax/libs/twitter-bootstrap/5.1.3/css/bootstrap.min.css" rel="stylesheet">
    <style>
        /* 优化后的样式 */
        .dashboard-container {
            background: #f8f9fa;
            min-height: 100vh;
            padding: 2rem;
        }

        .header-bar {
            background: linear-gradient(135deg, #2c3e50, #3498db);
            color: white;
            padding: 1.5rem;
            margin: -2rem -2rem 2rem -2rem;
            box-shadow: 0 4px 12px rgba(0, 0, 0, 0.1);
        }

        .module-card {
            border: 1px solid rgba(44, 62, 80, 0.1);
            border-radius: 8px;
            transition: transform 0.3s ease;
            background: white;
            height: 100%;
        }

        .module-card:hover {
            transform: translateY(-5px);
            box-shadow: 0 5px 15px rgba(44, 62, 80, 0.1);
            background: #e9f5ff;
        }

        .module-title {
            color: #2c3e50;
            font-weight: 600;
            border-bottom: 2px solid #3498db;
            padding-bottom: 0.5rem;
        }

        .feature-list li {
            color: #666;
            font-size: 0.95rem;
            padding: 4px 0;
        }

        .module-row {
            margin-bottom: 2rem;
        }
    </style>
</head>

<body>
    <div class="dashboard-container">
        <!-- 头部信息栏 -->
        <div class="header-bar">
            <div class="d-flex justify-content-between align-items-center">
                <div class="user-info">
                    <div class="h5 mb-0"><?= htmlspecialchars($userInfo['username']) ?></div>
                    <small class="text-light">角色：<?= htmlspecialchars($displayRole) ?></small>
                </div>
                <h1 class="header-title mb-0">果易管系统</h1>
                <a href="./logout.php" class="btn btn-light">
                    <i class="fas fa-sign-out-alt"></i> 退出系统
                </a>
            </div>
        </div>

        <!-- 功能模块网格 - 修改为两行，每行5个模块 -->
        <div class="container-fluid">
            <!-- 第一行模块 -->
            <div class="row module-row">
                <?php for ($i = 0; $i < 5; $i++): ?>
                    <div class="col">
                        <a href="<?= htmlspecialchars($modules[$i]['url']) ?>" class="text-decoration-none">
                            <div class="card module-card">
                                <div class="card-body">
                                    <h5 class="module-title text-center mb-3"><?= htmlspecialchars($modules[$i]['name']) ?></h5>
                                    <ul class="feature-list list-unstyled mb-0">
                                        <?php foreach ($modules[$i]['features'] as $feature): ?>
                                            <li><?= htmlspecialchars($feature) ?></li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endfor; ?>
            </div>

            <!-- 第二行模块 -->
            <div class="row module-row">
                <?php for ($i = 5; $i < 10; $i++): ?>
                    <div class="col">
                        <a href="<?= htmlspecialchars($modules[$i]['url']) ?>" class="text-decoration-none">
                            <div class="card module-card">
                                <div class="card-body">
                                    <h5 class="module-title text-center mb-3"><?= htmlspecialchars($modules[$i]['name']) ?></h5>
                                    <ul class="feature-list list-unstyled mb-0">
                                        <?php foreach ($modules[$i]['features'] as $feature): ?>
                                            <li><?= htmlspecialchars($feature) ?></li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        </a>
                    </div>
                <?php endfor; ?>
            </div>
        </div>
    </div>

    <script src="https://cdn.bootcdn.net/ajax/libs/font-awesome/5.15.4/js/all.min.js"></script>
</body>

</html>