<?php
session_start();
require_once '../config.php';

// 定义订单状态转换函数
function get_order_status_text($status)
{
    $order_statuses = [
        'draft' => '草稿',
        'confirmed' => '已确认',
        'processing' => '处理中',
        'partially_shipped' => '部分发货',
        'shipped' => '已发货',
        'delivered' => '已送达',
        'cancelled' => '已取消'
    ];

    return isset($order_statuses[$status]) ? $order_statuses[$status] : $status;
}

// 检查用户是否登录
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 初始化变量
$error = '';
$success = '';
$order_types = ['online' => '线上订单', 'offline' => '线下订单', 'wholesale' => '批发订单', 'ecommerce' => '电商平台订单'];
$payment_statuses = ['pending' => '待付款', 'paid' => '已付款', 'partially_paid' => '部分付款', 'refunded' => '已退款'];
$order_statuses = ['draft' => '草稿', 'confirmed' => '已确认', 'processing' => '处理中', 'partially_shipped' => '部分发货', 'shipped' => '已发货', 'delivered' => '已送达', 'cancelled' => '已取消'];

// 检查是否提供了订单ID
if (!isset($_GET['id']) || empty($_GET['id'])) {
    $error = "未提供订单ID";
} else {
    $order_id = intval($_GET['id']);

    try {
        // 检查必要的表是否存在
        $required_tables = [
            'sales_orders' => ['id', 'order_number', 'customer_id', 'sales_channel_id', 'order_date', 'total_amount', 'status', 'notes'],
            'sales_order_items' => ['id', 'sales_order_id', 'product_id', 'quantity', 'unit_price', 'item_total_amount'],
            'customers' => ['id', 'name', 'contact_person', 'phone', 'address'],
            'products' => ['id', 'name', 'unit']
        ];

        foreach ($required_tables as $table => $columns) {
            // 检查表是否存在
            $table_exists = $pdo->query("SHOW TABLES LIKE '$table'")->rowCount() > 0;
            if (!$table_exists) {
                throw new Exception("表 $table 不存在");
            }

            // 检查列是否存在
            $table_columns = $pdo->query("SHOW COLUMNS FROM $table")->fetchAll(PDO::FETCH_COLUMN);
            $missing_columns = array_diff($columns, $table_columns);
            if (!empty($missing_columns)) {
                throw new Exception("表 $table 缺少以下列: " . implode(', ', $missing_columns));
            }
        }

        // 获取销售渠道列表
        $stmt = $pdo->query("SELECT id, name FROM sales_channels ORDER BY name");
        $sales_channels = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 获取客户列表
        $stmt = $pdo->query("SELECT id, name FROM customers ORDER BY name");
        $customers = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 获取成品列表
        $stmt = $pdo->query("SELECT id, name, unit, specification, standard_price FROM products WHERE type = 'finished' ORDER BY name");
        $products = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 获取订单基本信息
        $stmt = $pdo->prepare("
            SELECT * 
            FROM sales_orders 
            WHERE id = ?
        ");
        $stmt->execute([$order_id]);
        $order = $stmt->fetch(PDO::FETCH_ASSOC);

        if (!$order) {
            throw new Exception("未找到ID为 {$order_id} 的订单");
        }

        // 订单状态不是草稿，不允许编辑
        if ($order['status'] != 'draft') {
            throw new Exception("只有草稿状态的订单才能编辑");
        }

        // 获取订单明细
        $stmt = $pdo->prepare("
            SELECT soi.*, p.name as product_name, p.unit
            FROM sales_order_items soi
            JOIN products p ON soi.product_id = p.id
            WHERE soi.sales_order_id = ?
        ");
        $stmt->execute([$order_id]);
        $order_items = $stmt->fetchAll(PDO::FETCH_ASSOC);

        // 处理表单提交
        if ($_SERVER['REQUEST_METHOD'] === 'POST') {
            try {
                $pdo->beginTransaction();

                $customer_id = $_POST['customer_id'];
                $sales_channel_id = $_POST['sales_channel_id'];
                $order_date = $_POST['order_date'];
                $required_date = !empty($_POST['required_date']) ? $_POST['required_date'] : null;
                $order_type = $_POST['order_type'];
                $status = $_POST['status'];
                $shipping_address = $_POST['shipping_address'];
                $notes = $_POST['notes'];

                // 更新订单基本信息
                $stmt = $pdo->prepare("
                    UPDATE sales_orders
                    SET customer_id = ?,
                        sales_channel_id = ?,
                        order_date = ?,
                        required_date = ?,
                        status = ?,
                        shipping_address = ?,
                        notes = ?
                    WHERE id = ?
                ");
                $stmt->execute([
                    $customer_id,
                    $sales_channel_id,
                    $order_date,
                    $required_date,
                    $status,
                    $shipping_address,
                    $notes,
                    $order_id
                ]);

                // 删除原有的订单明细项
                $stmt = $pdo->prepare("DELETE FROM sales_order_items WHERE sales_order_id = ?");
                $stmt->execute([$order_id]);

                // 添加新的订单明细项
                $product_ids = $_POST['product_id'] ?? [];
                $quantities = $_POST['quantity'] ?? [];
                $unit_prices = $_POST['unit_price'] ?? [];

                $total_amount = 0;

                for ($i = 0; $i < count($product_ids); $i++) {
                    if (empty($product_ids[$i]) || empty($quantities[$i]) || empty($unit_prices[$i])) {
                        continue;
                    }

                    $product_id = intval($product_ids[$i]);
                    $quantity = floatval($quantities[$i]);
                    $unit_price = floatval($unit_prices[$i]);
                    $subtotal = $quantity * $unit_price;
                    $total_amount += $subtotal;

                    $stmt = $pdo->prepare("
                        INSERT INTO sales_order_items (
                            sales_order_id, product_id, quantity, unit_price
                        ) VALUES (?, ?, ?, ?)
                    ");
                    $stmt->execute([$order_id, $product_id, $quantity, $unit_price]);
                }

                // 更新订单总金额
                $stmt = $pdo->prepare("UPDATE sales_orders SET total_amount = ? WHERE id = ?");
                $stmt->execute([$total_amount, $order_id]);

                $pdo->commit();
                $success = "订单更新成功！";

                // 成功后跳转到订单列表页面
                header("Location: order_list.php");
                exit;
            } catch (Exception $e) {
                $pdo->rollBack();
                $error = "更新订单失败: " . $e->getMessage();
            }
        }
    } catch (Exception $e) {
        $error = $e->getMessage();
    }
}
?>
<!DOCTYPE html>
<html lang="zh-CN">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>编辑订单 - FruitEase</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        /* 通用样式补充 */
        body {
            background-color: #f5f7fa;
            font-family: "Microsoft YaHei", Arial, sans-serif;
        }

        .container {
            padding: 20px;
            max-width: 1200px;
            margin: 0 auto;
        }

        h1 {
            color: #333;
            margin-bottom: 20px;
            font-size: 24px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eaeaea;
        }

        .section {
            margin-bottom: 30px;
            background: white;
            padding: 20px;
            border-radius: 8px;
            box-shadow: 0 2px 10px rgba(0, 0, 0, 0.05);
            border: 1px solid #eaeaea;
        }

        .section h2 {
            margin-top: 0;
            font-size: 18px;
            color: #444;
            border-bottom: 2px solid #f5f5f5;
            padding-bottom: 10px;
            margin-bottom: 20px;
        }

        /* 表单样式优化 */
        .form-group {
            margin-bottom: 15px;
        }

        .form-group label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
            color: #555;
            font-size: 14px;
        }

        .form-group input[type="date"],
        .form-group input[type="text"],
        .form-group input[type="number"],
        .form-group select,
        .form-group textarea {
            width: 100%;
            padding: 10px;
            border: 1px solid #ddd;
            border-radius: 4px;
            background-color: #fff;
            box-sizing: border-box;
            font-size: 14px;
            transition: border-color 0.3s;
        }

        .form-group input:focus,
        .form-group select:focus,
        .form-group textarea:focus {
            border-color: #3498db;
            outline: none;
            box-shadow: 0 0 5px rgba(52, 152, 219, 0.3);
        }

        .form-group textarea {
            resize: vertical;
            min-height: 80px;
        }

        .row {
            display: flex;
            flex-wrap: wrap;
            margin-right: -10px;
            margin-left: -10px;
        }

        .col-md-4,
        .col-md-6,
        .col-md-12 {
            padding-right: 10px;
            padding-left: 10px;
            box-sizing: border-box;
        }

        .col-md-4 {
            flex: 0 0 33.333333%;
            max-width: 33.333333%;
        }

        .col-md-6 {
            flex: 0 0 50%;
            max-width: 50%;
        }

        .col-md-12 {
            flex: 0 0 100%;
            max-width: 100%;
        }

        /* 订单明细样式 */
        .order-items-container {
            margin-top: 20px;
        }

        .order-item {
            display: flex;
            flex-wrap: wrap;
            margin-bottom: 10px;
            padding: 10px;
            background-color: #f9f9f9;
            border-radius: 4px;
            border: 1px solid #eee;
        }

        .order-item-col {
            padding: 0 5px;
        }

        .order-item-col-product {
            flex: 0 0 30%;
            max-width: 30%;
        }

        .order-item-col-quantity {
            flex: 0 0 20%;
            max-width: 20%;
        }

        .order-item-col-price {
            flex: 0 0 20%;
            max-width: 20%;
        }

        .order-item-col-subtotal {
            flex: 0 0 20%;
            max-width: 20%;
            font-weight: bold;
        }

        .order-item-col-actions {
            flex: 0 0 10%;
            max-width: 10%;
            text-align: right;
        }

        .add-item-btn {
            padding: 8px 15px;
            background: #28a745;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            margin-top: 10px;
        }

        .remove-item-btn {
            padding: 4px 8px;
            background: #dc3545;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-size: 12px;
        }

        /* 按钮样式 */
        .button,
        .btn-primary {
            padding: 10px 15px;
            background: #3498db;
            color: white;
            border: none;
            border-radius: 4px;
            cursor: pointer;
            font-weight: bold;
            text-align: center;
            text-decoration: none;
            display: inline-block;
            transition: background 0.3s;
        }

        .button:hover,
        .btn-primary:hover {
            background: #2980b9;
        }

        .button-group {
            display: flex;
            gap: 10px;
            margin-top: 20px;
        }

        .btn-secondary {
            background: #6c757d;
        }

        .btn-secondary:hover {
            background: #5a6268;
        }

        /* 消息样式 */
        .alert {
            padding: 15px;
            margin-bottom: 20px;
            border-radius: 4px;
            display: flex;
            align-items: center;
        }

        .alert-success {
            background-color: #d4edda;
            color: #155724;
            border: 1px solid #c3e6cb;
        }

        .alert-danger {
            background-color: #f8d7da;
            color: #721c24;
            border: 1px solid #f5c6cb;
        }

        /* 响应式 */
        @media (max-width: 768px) {

            .col-md-4,
            .col-md-6 {
                flex: 0 0 100%;
                max-width: 100%;
            }

            .order-item-col {
                flex: 0 0 100%;
                max-width: 100%;
                margin-bottom: 10px;
            }
        }
    </style>
</head>

<body>
    <div class="container">
        <h1>编辑订单</h1>

        <?php if (!empty($error)): ?>
            <div class="alert alert-danger"><?= htmlspecialchars($error) ?></div>
        <?php endif; ?>

        <?php if (!empty($success)): ?>
            <div class="alert alert-success"><?= htmlspecialchars($success) ?></div>
        <?php endif; ?>

        <?php if (empty($error) || !empty($success)): ?>
            <form method="POST" action="">
                <div class="section">
                    <h2>基本信息</h2>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="order_number">订单编号</label>
                                <input type="text" id="order_number" name="order_number" value="<?= htmlspecialchars($order['order_number']) ?>" readonly>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="order_date">订单日期</label>
                                <input type="date" id="order_date" name="order_date" value="<?= htmlspecialchars(substr($order['order_date'], 0, 10)) ?>" required>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="customer_id">客户</label>
                                <select id="customer_id" name="customer_id" required>
                                    <option value="">-- 选择客户 --</option>
                                    <?php foreach ($customers as $customer): ?>
                                        <option value="<?= $customer['id'] ?>" <?= $order['customer_id'] == $customer['id'] ? 'selected' : '' ?>>
                                            <?= htmlspecialchars($customer['name']) ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                        <div class="col-md-6">
                            <div class="form-group">
                                <label for="sales_channel_id">销售渠道</label>
                                <select id="sales_channel_id" name="sales_channel_id">
                                    <option value="">-- 选择渠道 --</option>
                                    <?php foreach ($sales_channels as $channel): ?>
                                        <option value="<?= $channel['id'] ?>" <?= $order['sales_channel_id'] == $channel['id'] ? 'selected' : '' ?>>
                                            <?= htmlspecialchars($channel['name']) ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-4">
                            <div class="form-group">
                                <label for="order_type">订单类型</label>
                                <select name="order_type" id="order_type" class="form-control" required>
                                    <?php foreach ($order_types as $key => $value): ?>
                                        <option value="<?= $key ?>" <?= $order['order_type'] == $key ? 'selected' : '' ?>>
                                            <?= $value ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group">
                                <label for="status">订单状态</label>
                                <select name="status" id="status" class="form-control" required>
                                    <?php foreach ($order_statuses as $key => $value): ?>
                                        <option value="<?= $key ?>" <?= $order['status'] == $key ? 'selected' : '' ?>>
                                            <?= $value ?>
                                        </option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                        </div>
                        <div class="col-md-4">
                            <div class="form-group">
                                <label for="required_date">要求交货日期</label>
                                <input type="date" id="required_date" name="required_date" value="<?= !empty($order['required_date']) ? htmlspecialchars(substr($order['required_date'], 0, 10)) : '' ?>">
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-group">
                                <label for="shipping_address">收货地址</label>
                                <textarea id="shipping_address" name="shipping_address" rows="3"><?= htmlspecialchars($order['shipping_address'] ?? '') ?></textarea>
                            </div>
                        </div>
                    </div>
                    <div class="row">
                        <div class="col-md-12">
                            <div class="form-group">
                                <label for="notes">备注</label>
                                <textarea id="notes" name="notes" rows="3"><?= htmlspecialchars($order['notes'] ?? '') ?></textarea>
                            </div>
                        </div>
                    </div>
                </div>

                <div class="section">
                    <h2>订单明细</h2>
                    <div id="order-items">
                        <?php foreach ($order_items as $index => $item): ?>
                            <div class="order-item">
                                <div class="order-item-col order-item-col-product">
                                    <div class="form-group">
                                        <label>产品</label>
                                        <select name="product_id[]" required onchange="updateProductInfo(this, <?= $index ?>)">
                                            <option value="">-- 选择产品 --</option>
                                            <?php foreach ($products as $product): ?>
                                                <option value="<?= $product['id'] ?>" data-price="<?= $product['standard_price'] ?>" data-unit="<?= htmlspecialchars($product['unit']) ?>" <?= $item['product_id'] == $product['id'] ? 'selected' : '' ?>>
                                                    <?= htmlspecialchars($product['name']) ?> (<?= htmlspecialchars($product['specification'] ?: '无规格') ?>)
                                                </option>
                                            <?php endforeach; ?>
                                        </select>
                                    </div>
                                </div>
                                <div class="order-item-col order-item-col-quantity">
                                    <div class="form-group">
                                        <label>数量</label>
                                        <input type="number" name="quantity[]" value="<?= $item['quantity'] ?>" min="0.01" step="0.01" required onchange="calculateSubtotal(<?= $index ?>)">
                                    </div>
                                </div>
                                <div class="order-item-col order-item-col-price">
                                    <div class="form-group">
                                        <label>单价</label>
                                        <input type="number" name="unit_price[]" id="unit_price_<?= $index ?>" value="<?= $item['unit_price'] ?>" min="0.01" step="0.01" required onchange="calculateSubtotal(<?= $index ?>)">
                                    </div>
                                </div>
                                <div class="order-item-col order-item-col-subtotal">
                                    <div class="form-group">
                                        <label>小计</label>
                                        <input type="text" id="subtotal_<?= $index ?>" value="￥<?= number_format($item['quantity'] * $item['unit_price'], 2) ?>" readonly>
                                    </div>
                                </div>
                                <div class="order-item-col order-item-col-actions">
                                    <div class="form-group">
                                        <label>&nbsp;</label>
                                        <button type="button" class="remove-item-btn" onclick="removeOrderItem(this)">删除</button>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                    <button type="button" class="add-item-btn" onclick="addOrderItem()">添加商品</button>
                </div>

                <div class="button-group">
                    <a href="order_detail.php?id=<?= $order_id ?>" class="button btn-secondary">返回详情</a>
                    <button type="submit" class="button btn-primary">保存订单</button>
                </div>
            </form>

            <template id="order-item-template">
                <div class="order-item">
                    <div class="order-item-col order-item-col-product">
                        <div class="form-group">
                            <label>产品</label>
                            <select name="product_id[]" required onchange="updateProductInfo(this, __INDEX__)">
                                <option value="">-- 选择产品 --</option>
                                <?php foreach ($products as $product): ?>
                                    <option value="<?= $product['id'] ?>" data-price="<?= $product['standard_price'] ?>" data-unit="<?= htmlspecialchars($product['unit']) ?>">
                                        <?= htmlspecialchars($product['name']) ?> (<?= htmlspecialchars($product['specification'] ?: '无规格') ?>)
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="order-item-col order-item-col-quantity">
                        <div class="form-group">
                            <label>数量</label>
                            <input type="number" name="quantity[]" value="1" min="0.01" step="0.01" required onchange="calculateSubtotal(__INDEX__)">
                        </div>
                    </div>
                    <div class="order-item-col order-item-col-price">
                        <div class="form-group">
                            <label>单价</label>
                            <input type="number" name="unit_price[]" id="unit_price___INDEX__" value="0" min="0.01" step="0.01" required onchange="calculateSubtotal(__INDEX__)">
                        </div>
                    </div>
                    <div class="order-item-col order-item-col-subtotal">
                        <div class="form-group">
                            <label>小计</label>
                            <input type="text" id="subtotal___INDEX__" value="￥0.00" readonly>
                        </div>
                    </div>
                    <div class="order-item-col order-item-col-actions">
                        <div class="form-group">
                            <label>&nbsp;</label>
                            <button type="button" class="remove-item-btn" onclick="removeOrderItem(this)">删除</button>
                        </div>
                    </div>
                </div>
            </template>

            <script>
                let itemIndex = <?= count($order_items) ?>;

                function addOrderItem() {
                    const template = document.getElementById('order-item-template').innerHTML;
                    const newItem = template.replace(/__INDEX__/g, itemIndex);
                    document.getElementById('order-items').insertAdjacentHTML('beforeend', newItem);
                    itemIndex++;
                }

                function removeOrderItem(button) {
                    const orderItem = button.closest('.order-item');
                    orderItem.remove();
                }

                function updateProductInfo(select, index) {
                    const option = select.options[select.selectedIndex];
                    if (option.value) {
                        const price = option.getAttribute('data-price');
                        document.getElementById(`unit_price_${index}`).value = price;
                        calculateSubtotal(index);
                    }
                }

                function calculateSubtotal(index) {
                    const quantity = parseFloat(document.getElementsByName('quantity[]')[index].value) || 0;
                    const unitPrice = parseFloat(document.getElementsByName('unit_price[]')[index].value) || 0;
                    const subtotal = quantity * unitPrice;
                    document.getElementById(`subtotal_${index}`).value = `￥${subtotal.toFixed(2)}`;
                }

                // 如果没有订单项，默认添加一个空项
                if (itemIndex === 0) {
                    addOrderItem();
                }
            </script>
        <?php endif; ?>
    </div>
</body>

</html>