<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取订单ID
$order_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$order_id) {
    $_SESSION['error'] = "未指定订单ID";
    header("Location: purchase_orders.php");
    exit;
}

try {
    // 获取采购订单信息
    $stmt = $pdo->prepare("
        SELECT 
            po.id, 
            po.order_number, 
            po.status, 
            po.total_amount,
            s.name AS supplier_name
        FROM purchase_orders po
        JOIN suppliers s ON po.supplier_id = s.id
        WHERE po.id = ?
    ");
    $stmt->execute([$order_id]);
    $order = $stmt->fetch();

    if (!$order) {
        $_SESSION['error'] = "找不到该采购订单";
        header("Location: purchase_orders.php");
        exit;
    }

    // 检查订单状态是否允许取消（只有待审批或已批准状态可以取消）
    if (!in_array($order['status'], ['pending', 'approved'])) {
        $_SESSION['error'] = "当前状态的订单不能取消";
        header("Location: purchase_order_detail.php?id=" . $order_id);
        exit;
    }

    // 处理取消操作
    $pdo->beginTransaction();

    // 更新订单状态为已取消
    $stmt = $pdo->prepare("
        UPDATE purchase_orders 
        SET status = 'cancelled' 
        WHERE id = ?
    ");
    $stmt->execute([$order_id]);

    // 记录操作日志
    $stmt = $pdo->prepare("
        INSERT INTO activity_log 
        (user_id, username, action, target_type, target_id, details, ip_address) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");
    $stmt->execute([
        $_SESSION['user_id'],
        $_SESSION['username'],
        '取消采购订单',
        'purchase_order',
        $order_id,
        json_encode([
            'order_number' => $order['order_number'],
            'supplier_name' => $order['supplier_name'],
            'total_amount' => $order['total_amount']
        ]),
        $_SERVER['REMOTE_ADDR']
    ]);

    $pdo->commit();
    $_SESSION['success'] = "已成功取消采购订单 " . $order['order_number'];
} catch (PDOException $e) {
    if (isset($pdo) && $pdo->inTransaction()) {
        $pdo->rollBack();
    }
    $_SESSION['error'] = "数据库错误：" . $e->getMessage();
}

// 返回订单详情页
header("Location: purchase_order_detail.php?id=" . $order_id);
exit;
