<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 获取所有采购订单
try {
    $stmt = $pdo->query("
        SELECT 
            po.id, 
            po.order_number, 
            s.name AS supplier_name,
            po.order_date, 
            po.expected_delivery_date, 
            po.total_amount, 
            po.status,
            (SELECT SUM(received_quantity) FROM purchase_order_items WHERE purchase_order_id = po.id) AS total_received,
            (SELECT SUM(quantity) FROM purchase_order_items WHERE purchase_order_id = po.id) AS total_ordered
        FROM purchase_orders po
        JOIN suppliers s ON po.supplier_id = s.id
        ORDER BY po.order_date DESC, po.id DESC
    ");
    $orders = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取采购订单失败：" . $e->getMessage();
}

// 获取所有供应商（用于新订单创建）
try {
    $stmt = $pdo->query("SELECT id, name FROM suppliers ORDER BY name");
    $suppliers = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取供应商失败：" . $e->getMessage();
}

// 获取原材料列表（用于新订单创建）
try {
    $stmt = $pdo->query("
        SELECT id, name, unit, specification 
        FROM products 
        WHERE type = 'raw' 
        ORDER BY name
    ");
    $materials = $stmt->fetchAll();
} catch (PDOException $e) {
    $error = "获取原材料失败：" . $e->getMessage();
}

// 状态显示映射
$statusDisplay = [
    'pending' => ['text' => '待审批', 'class' => '待处理'],
    'approved' => ['text' => '已审批', 'class' => '进行中'],
    'ordered' => ['text' => '已下单', 'class' => '进行中'],
    'partially_received' => ['text' => '部分入库', 'class' => '进行中'],
    'received' => ['text' => '已完成', 'class' => '已完成'],
    'cancelled' => ['text' => '已取消', 'class' => '待处理']
];
?>
<!DOCTYPE html>
<html>

<head>
    <title>原材料采购管理</title>
    <link rel="stylesheet" href="./style.css">
    <style>
        .order-card {
            border: 1px solid #ddd;
            border-radius: 8px;
            padding: 15px;
            margin-bottom: 15px;
            background-color: #fff;
        }

        .order-header {
            display: flex;
            justify-content: space-between;
            align-items: center;
            border-bottom: 1px solid #eee;
            padding-bottom: 10px;
            margin-bottom: 10px;
        }

        .order-number {
            font-size: 18px;
            font-weight: bold;
            color: #2c3e50;
        }

        .order-info {
            display: grid;
            grid-template-columns: 1fr 1fr 1fr;
            gap: 10px;
        }

        .info-item {
            margin-bottom: 5px;
        }

        .info-label {
            font-weight: bold;
            color: #555;
        }

        .progress-container {
            margin-top: 10px;
            background-color: #f5f5f5;
            border-radius: 4px;
            height: 20px;
            overflow: hidden;
        }

        .progress-bar {
            height: 100%;
            background-color: #3498db;
            text-align: center;
            color: white;
            font-size: 12px;
            line-height: 20px;
        }

        /* 新增用于订单创建的样式 */
        .new-order-form {
            background-color: #f9f9f9;
            border-radius: 8px;
            padding: 20px;
            margin-bottom: 20px;
        }

        .form-row {
            display: flex;
            gap: 15px;
            margin-bottom: 15px;
        }

        .form-col {
            flex: 1;
        }

        .materials-list {
            border: 1px solid #ddd;
            border-radius: 4px;
            padding: 15px;
            margin-top: 15px;
            background-color: #fff;
        }

        .material-item {
            display: flex;
            gap: 15px;
            margin-bottom: 10px;
            padding-bottom: 10px;
            border-bottom: 1px solid #eee;
        }

        .material-item:last-child {
            border-bottom: none;
        }

        .add-material-btn {
            background-color: #28a745;
            color: white;
            border: none;
            padding: 8px 15px;
            border-radius: 4px;
            cursor: pointer;
            margin-top: 10px;
        }

        .add-material-btn:hover {
            background-color: #218838;
        }

        .remove-material-btn {
            background-color: #dc3545;
            color: white;
            border: none;
            padding: 4px 8px;
            border-radius: 4px;
            cursor: pointer;
            font-size: 12px;
        }

        .remove-material-btn:hover {
            background-color: #c82333;
        }
    </style>
</head>

<body>
    <div class="container">
        <h2>原材料采购管理</h2>

        <?php if (isset($error)): ?>
            <div class="alert alert-danger"><?= $error ?></div>
        <?php endif; ?>

        <?php if (isset($_SESSION['success'])): ?>
            <div class="alert alert-success"><?= $_SESSION['success'] ?></div>
            <?php unset($_SESSION['success']); ?>
        <?php endif; ?>

        <?php if (isset($_SESSION['error'])): ?>
            <div class="alert alert-danger"><?= $_SESSION['error'] ?></div>
            <?php unset($_SESSION['error']); ?>
        <?php endif; ?>

        <!-- 创建新订单按钮 -->
        <div style="margin-bottom: 20px;">
            <button id="showNewOrderForm" class="btn" style="background-color: #28a745;">创建新采购订单</button>
        </div>

        <!-- 新订单表单（默认隐藏） -->
        <div id="newOrderForm" class="new-order-form" style="display: none;">
            <h3>创建新采购订单</h3>
            <form method="POST" action="purchase_order_create.php">
                <?= csrf_field() ?>

                <div class="form-row">
                    <div class="form-col">
                        <div class="form-group">
                            <label>供应商</label>
                            <select name="supplier_id" required>
                                <option value="">请选择供应商</option>
                                <?php foreach ($suppliers as $supplier): ?>
                                    <option value="<?= $supplier['id'] ?>"><?= htmlspecialchars($supplier['name']) ?></option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                    </div>
                    <div class="form-col">
                        <div class="form-group">
                            <label>订单日期</label>
                            <input type="date" name="order_date" value="<?= date('Y-m-d') ?>" required>
                        </div>
                    </div>
                    <div class="form-col">
                        <div class="form-group">
                            <label>预计交货日期</label>
                            <input type="date" name="expected_delivery_date" required>
                        </div>
                    </div>
                </div>

                <div class="materials-list">
                    <h4>采购明细</h4>
                    <div id="materialItems">
                        <div class="material-item">
                            <div class="form-group" style="flex: 3;">
                                <label>原材料</label>
                                <select name="materials[0][product_id]" required>
                                    <option value="">请选择原材料</option>
                                    <?php foreach ($materials as $material): ?>
                                        <option value="<?= $material['id'] ?>"><?= htmlspecialchars($material['name']) ?> (<?= htmlspecialchars($material['specification'] ?? '无规格') ?>)</option>
                                    <?php endforeach; ?>
                                </select>
                            </div>
                            <div class="form-group" style="flex: 1;">
                                <label>数量</label>
                                <input type="number" name="materials[0][quantity]" step="0.01" min="0.01" required>
                            </div>
                            <div class="form-group" style="flex: 1;">
                                <label>单价</label>
                                <input type="number" name="materials[0][unit_price]" step="0.01" min="0.01" required>
                            </div>
                            <div class="form-group" style="flex: 0;">
                                <label>&nbsp;</label>
                                <button type="button" class="remove-material-btn" style="visibility: hidden;">删除</button>
                            </div>
                        </div>
                    </div>

                    <button type="button" id="addMaterialBtn" class="add-material-btn">+ 添加原材料</button>
                </div>

                <div class="form-group" style="margin-top: 20px;">
                    <button type="submit" class="btn">提交采购订单</button>
                    <button type="button" id="cancelNewOrder" class="btn" style="background-color: #6c757d; margin-left: 10px;">取消</button>
                </div>
            </form>
        </div>

        <!-- 采购订单列表 -->
        <div class="table-container">
            <h3>采购订单列表</h3>

            <?php if (empty($orders)): ?>
                <div class="empty-state">
                    <p>暂无采购订单记录</p>
                </div>
            <?php else: ?>
                <?php foreach ($orders as $order): ?>
                    <?php
                    // 计算进度百分比
                    $progress = 0;
                    if ($order['total_ordered'] > 0 && $order['total_received'] !== null) {
                        $progress = min(100, round(($order['total_received'] / $order['total_ordered']) * 100));
                    }

                    // 根据状态确定显示样式
                    $statusInfo = $statusDisplay[$order['status']] ?? ['text' => $order['status'], 'class' => ''];
                    ?>
                    <div class="order-card">
                        <div class="order-header">
                            <div class="order-number"><?= htmlspecialchars($order['order_number']) ?></div>
                            <div class="status-tag <?= $statusInfo['class'] ?>"><?= $statusInfo['text'] ?></div>
                        </div>
                        <div class="order-info">
                            <div class="info-item">
                                <span class="info-label">供应商：</span>
                                <?= htmlspecialchars($order['supplier_name']) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">订单日期：</span>
                                <?= date('Y-m-d', strtotime($order['order_date'])) ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">预计交货日期：</span>
                                <?= $order['expected_delivery_date'] ? date('Y-m-d', strtotime($order['expected_delivery_date'])) : '未设置' ?>
                            </div>
                            <div class="info-item">
                                <span class="info-label">订单金额：</span>
                                ¥<?= number_format($order['total_amount'], 2) ?>
                            </div>
                            <div class="info-item" style="grid-column: 2 / span 2;">
                                <span class="info-label">入库进度：</span>
                                <div class="progress-container">
                                    <div class="progress-bar" style="width: <?= $progress ?>%">
                                        <?= $progress ?>%
                                    </div>
                                </div>
                            </div>
                        </div>
                        <div style="margin-top: 10px; text-align: right;">
                            <a href="purchase_order_detail.php?id=<?= $order['id'] ?>" class="btn-link">查看详情</a>
                            <?php if ($order['status'] === 'pending'): ?>
                                <a href="purchase_order_edit.php?id=<?= $order['id'] ?>" class="btn-edit">编辑</a>
                                <a href="purchase_order_approve.php?id=<?= $order['id'] ?>"
                                    onclick="return confirm('确认审批该采购订单？')"
                                    class="btn-edit" style="background-color: #28a745;">审批</a>
                            <?php elseif ($order['status'] === 'approved'): ?>
                                <a href="purchase_order_place.php?id=<?= $order['id'] ?>"
                                    onclick="return confirm('确认已下单给供应商？')"
                                    class="btn-edit" style="background-color: #fd7e14;">确认下单</a>
                            <?php elseif (in_array($order['status'], ['ordered', 'partially_received'])): ?>
                                <a href="material_receiving.php?order_id=<?= $order['id'] ?>"
                                    class="btn-edit" style="background-color: #28a745;">录入收货</a>
                            <?php endif; ?>

                            <?php if ($order['status'] === 'pending'): ?>
                                <a href="purchase_order_cancel.php?id=<?= $order['id'] ?>"
                                    onclick="return confirm('确认取消该采购订单？此操作不可恢复')"
                                    class="btn-delete">取消</a>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
    </div>

    <script>
        // 显示/隐藏新订单表单
        document.getElementById('showNewOrderForm').addEventListener('click', function() {
            document.getElementById('newOrderForm').style.display = 'block';
            this.style.display = 'none';
        });

        document.getElementById('cancelNewOrder').addEventListener('click', function() {
            document.getElementById('newOrderForm').style.display = 'none';
            document.getElementById('showNewOrderForm').style.display = 'block';
        });

        // 添加/删除原材料项
        let materialIndex = 0;

        document.getElementById('addMaterialBtn').addEventListener('click', function() {
            materialIndex++;
            const materialItems = document.getElementById('materialItems');
            const newItem = document.createElement('div');
            newItem.className = 'material-item';

            newItem.innerHTML = `
                <div class="form-group" style="flex: 3;">
                    <label>原材料</label>
                    <select name="materials[${materialIndex}][product_id]" required>
                        <option value="">请选择原材料</option>
                        <?php foreach ($materials as $material): ?>
                            <option value="<?= $material['id'] ?>"><?= htmlspecialchars($material['name']) ?> (<?= htmlspecialchars($material['specification'] ?? '无规格') ?>)</option>
                        <?php endforeach; ?>
                    </select>
                </div>
                <div class="form-group" style="flex: 1;">
                    <label>数量</label>
                    <input type="number" name="materials[${materialIndex}][quantity]" step="0.01" min="0.01" required>
                </div>
                <div class="form-group" style="flex: 1;">
                    <label>单价</label>
                    <input type="number" name="materials[${materialIndex}][unit_price]" step="0.01" min="0.01" required>
                </div>
                <div class="form-group" style="flex: 0;">
                    <label>&nbsp;</label>
                    <button type="button" class="remove-material-btn">删除</button>
                </div>
            `;

            materialItems.appendChild(newItem);

            // 为新添加的删除按钮绑定事件
            const removeBtn = newItem.querySelector('.remove-material-btn');
            removeBtn.addEventListener('click', function() {
                materialItems.removeChild(newItem);
            });
        });
    </script>
</body>

</html>