<?php
session_start();
require_once '../config.php';

// 检查登录状态
if (!isset($_SESSION['user_id'])) {
    header("Location: ../login.php");
    exit;
}

// 表单处理
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    // CSRF验证
    if (!isset($_POST['csrf_token']) || $_POST['csrf_token'] !== $_SESSION['csrf_token']) {
        $_SESSION['error'] = "安全验证失败，请重试";
        header("Location: supplier_management.php");
        exit;
    }

    // 获取表单数据
    $name = trim($_POST['name'] ?? '');
    $contact_person = trim($_POST['contact_person'] ?? '');
    $phone = trim($_POST['phone'] ?? '');
    $address = trim($_POST['address'] ?? '');
    $rating = !empty($_POST['rating']) ? (int)$_POST['rating'] : null;

    // 验证数据
    if (empty($name)) {
        $_SESSION['error'] = "供应商名称不能为空";
        header("Location: supplier_management.php");
        exit;
    }

    try {
        $pdo->beginTransaction();

        // 检查供应商名称是否已存在
        $stmt = $pdo->prepare("SELECT COUNT(*) FROM suppliers WHERE name = ?");
        $stmt->execute([$name]);
        if ($stmt->fetchColumn() > 0) {
            throw new Exception("供应商名称已存在");
        }

        // 插入供应商记录
        $stmt = $pdo->prepare("
            INSERT INTO suppliers (name, contact_person, phone, address, rating) 
            VALUES (?, ?, ?, ?, ?)
        ");
        $stmt->execute([$name, $contact_person, $phone, $address, $rating]);
        $supplierId = $pdo->lastInsertId();

        // 记录操作日志
        $stmt = $pdo->prepare("
            INSERT INTO activity_log 
            (user_id, username, action, target_type, target_id, details, ip_address) 
            VALUES (?, ?, ?, ?, ?, ?, ?)
        ");
        $stmt->execute([
            $_SESSION['user_id'],
            $_SESSION['username'],
            '创建供应商',
            'supplier',
            $supplierId,
            json_encode([
                'name' => $name,
                'contact_person' => $contact_person,
                'phone' => $phone,
                'address' => $address,
                'rating' => $rating
            ]),
            $_SERVER['REMOTE_ADDR']
        ]);

        $pdo->commit();
        $_SESSION['success'] = "供应商添加成功";
    } catch (PDOException $e) {
        $pdo->rollBack();
        $_SESSION['error'] = "操作失败：" . $e->getMessage();
    } catch (Exception $e) {
        $pdo->rollBack();
        $_SESSION['error'] = $e->getMessage();
    }

    header("Location: supplier_management.php");
    exit;
} else {
    // 非POST请求直接跳转到管理页面
    header("Location: supplier_management.php");
    exit;
}
