<?php
session_start();
require_once '../config.php';

// 检查权限
if (!is_admin()) {
    header("HTTP/1.1 403 Forbidden");
    exit("<div class='alert alert-danger'>权限不足，无法访问此页面</div>");
}

// 获取用户ID
$user_id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if ($user_id <= 0) {
    header("Location: user_management.php");
    exit;
}

try {
    $pdo->beginTransaction();

    // 获取用户信息
    $stmt = $pdo->prepare("SELECT username, is_active FROM users WHERE id = ?");
    $stmt->execute([$user_id]);
    $user = $stmt->fetch(PDO::FETCH_ASSOC);

    if (!$user) {
        throw new Exception("用户不存在");
    }

    if ($user['is_active']) {
        throw new Exception("该用户已处于启用状态");
    }

    // 更新用户状态
    $stmt = $pdo->prepare("UPDATE users SET is_active = 1, updated_at = CURRENT_TIMESTAMP WHERE id = ?");
    $stmt->execute([$user_id]);

    // 记录操作日志
    $stmt = $pdo->prepare("
        INSERT INTO activity_log 
        (user_id, username, action, target_type, target_id, details, ip_address) 
        VALUES (?, ?, ?, ?, ?, ?, ?)
    ");

    $stmt->execute([
        $_SESSION['user_id'],
        $_SESSION['username'],
        '启用用户',
        'user',
        $user_id,
        json_encode(['activated_user' => $user['username']]),
        $_SERVER['REMOTE_ADDR']
    ]);

    $pdo->commit();
    $_SESSION['success'] = "用户 '{$user['username']}' 已成功启用";
} catch (Exception $e) {
    $pdo->rollBack();
    $_SESSION['error'] = $e->getMessage();
}

header("Location: user_management.php");
exit;
